#
# spec file for package foot
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _distconfdir %{_sysconfdir}
%endif
Name:           foot
Version:        1.21.0
Release:        1.1
Summary:        A Wayland terminal emulator
License:        MIT
URL:            https://codeberg.org/dnkl/foot
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
# https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xb19964fbba09664cc81027ed5bbd4992c116573f
Source2:        %{name}.keyring
Requires:       terminfo
%if 0%{?suse_version} < 1600
Requires:       utempter
%endif
BuildRequires:  meson >= 0.59
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scdoc
BuildRequires:  pkgconfig(fcft) < 4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.3.1
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(tic)
BuildRequires:  pkgconfig(tllist) >= 1.1.0
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.41
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(xkbcommon) >= 1.0.0

%description
A Wayland terminal emulator.

%package extra-terminfo

Summary:        Extra terminfo files for the foot terminal emulator
BuildArch:      noarch

%description extra-terminfo
This package contains extra terminfo files for the foot terminal emulator
that provide more features than the files in the terminfo-base package.
Set term=foot-extra or term=foot-extra-direct in foot.ini to
take advantage of the files in this package.

%package themes

Summary:        Community-contributed themes for the foot terminal emulator
Requires:       foot
BuildArch:      noarch

%description themes
This package contains popular themes for the foot terminal emulator providing
users an easy way to theme foot.

%prep
%autosetup -p1

%build
%meson \
	--sysconfdir "%{_distconfdir}" \
	-Db_lto=true \
	-Ddocs=enabled \
	-Dgrapheme-clustering=enabled \
	-Dime=true \
	-Dterminfo=enabled \
	-Dterminfo-base-name=foot-extra \
	-Dthemes=true \
%if 0%{?suse_version} < 1600
	-Dutmp-backend=libutempter \
	-Dutmp-default-helper-path=%{_libexecdir}/utempter/utempter
%else
	-Dutmp-backend=none
%endif
%meson_build

%install
%meson_install
rm -r %{buildroot}/%{_datadir}/doc/%{name}/

%check
%meson_test

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/foot
%{_bindir}/footclient
%{_datadir}/applications/foot.desktop
%{_datadir}/applications/footclient.desktop
%{_datadir}/applications/foot-server.desktop
%{_datadir}/bash-completion/
%{_datadir}/fish/
%{_datadir}/zsh/
%{_datadir}/icons/hicolor/
%dir %{_distconfdir}/xdg/%{name}
%{_distconfdir}/xdg/%{name}/foot.ini
%{_mandir}/man1/foot.1.gz
%{_mandir}/man1/footclient.1.gz
%{_mandir}/man5/foot.ini.5.gz
%{_mandir}/man7/foot-ctlseqs.7.gz
%{_userunitdir}/foot-server.service
%{_userunitdir}/foot-server.socket

%files extra-terminfo
%{_datadir}/terminfo/f/foot-extra
%{_datadir}/terminfo/f/foot-extra-direct

%files themes
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/themes

%changelog
* Mon Mar 17 2025 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.21.0:
  * foot.ini options:
  * Added bell.system option to use xdg-system-bell-v1 Wayland protocol
    to report the terminal bell. Defaults to "yes".
  * Added search-bindings.delete-to-start and .delete-to-end key bindings,
    defaulting to Ctrl+u and Ctrl+k respectively.
  * cursor.style can now be set to "hollow".
  * Added gamma-correct-blending option to use gamma-correct font rendering
    if the compositor supports wp_color_management_v1,
    specifically the ext_linear transfer function. Enabled by default when
    compositor support is available.
  * Added url.regex option to define a regex used to match URLs.
    The url.uri-characters and url-protocols options have been removed.
  * tweak.scaling-filter now supports more values when running with
    libfcft4 >= 3.3.1 - "impulse", "box", "linear", "gaussian", "lanczos2",
    "lanczos3-stretched". The scaling filter is no longer applied to
    scaled bitmap fonts when that is enabled in FontConfig.
  * Removed main.notify and main.notify-focus-when-inhibit options.
    These were deprecated in 1.18.0.
  * Fixed various issues with wrapped lines such as some such lines being
    copied as multiple lines, glitching when the window was resized, etc.
  * Fixed various issues with handling of zero-width characters,
    combining characters, etc.
  * Fixed various issues with Kitty keyboard protocol implementation.
  * Fixed wrong key bindings being executed when using
    alternative keyboard layouts.
  * Fixed various hangs, crashes and resource leaks.
  * Renamed theme tokyo-nightday to tokyo-nightlight and modified its colors.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.21.0 for more details.
- Remove "-Wno-error=deprecated-declarations" because issue has been
  fixed.
* Thu Mar 13 2025 Arnav Singh <opensuse@arnavion.dev>
- Temporarily disable warning-as-error for using deprecated functions,
  because foot currently uses a function that was deprecated in fcft 3.3.x
* Sat Jan 18 2025 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.20.2:
  * foot.ini options:
  * colors.flash-alpha can be set to 1.0 (fully opaque) again.
    The issue where this would cause window to be stuck in flash state
    has been fixed separately.
  * "Report window title" (CSI 21 t) and "Report app-id" (OSC 176 ?)
    are now ignored. This relates to CVEs reported in some other terminals
    where a malicious program / ssh remote can trick the user into running
    arbitrary commands by using these sequences to fill
    the shell input buffer.
  * Fixed a crash on startup if the compositor sent a keyboard enter event
    before the window was mapped.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.20.2 for more details.
* Fri Jan 17 2025 Thorsten Kukuk <kukuk@suse.com>
- Disable libutempter, it doesn't work anymore with the switch
  from utmp to systemd-logind
* Fri Jan  3 2025 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.20.1:
  * foot.ini options:
  * colors.flash-alpha can no longer be set to 1.0 (fully opaque).
  * App ID set using OSC 176 is now limited to 2048 characters.
  * Fixed a crash from printing certain Unicode characters.
  * Added new themes: iterm.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.20.1 for more details.
* Wed Jan  1 2025 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.20.0:
  * foot.ini options:
  * Added security.osc52 to partially or fully disable clipboard access
    via the OSC-52 escape sequence. Defaults to enabling clipboard access.
  * Various keybindings for search mode that were implemented previously but
    not documented have now been documented in the manpages.
  * Runtime changes to the window title and app ID now require the value
    to only contain printable characters.
  * Added new themes: rose-pine-dawn, rose-pine-moon.
  * Fixed various crashes.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.20.0 for more details.
* Wed Oct 23 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.19.0:
  * foot.ini options:
  * Added main.resize-keep-grid option to control whether the window is
    resized (and the grid reflowed) or not when zooming in/out.
  * Added main.strikeout-thickness option.
  * Added colors.sixelNN options to control the default sixel color palette.
  * Changed cursor.unfocused-style option to be effective when
    cursor.style is not "block".
  * Activating a notification that was triggered by OSC-777 or BEL now focuses
    the foot window, if XDG activation tokens are supported by
    the Wayland compositor, the notification daemon and the notification helper
    set in foot's desktop-notifications.command config.
  * The .desktop files have been renamed to remove
    the "org.codeberg.dnkl." prefix.
  * Fixed crash when setting the window title to invalid UTF-8.
  * Fixed misbehavior when the scrollback.lines config was set to a value
    that caused integer overflow.
  * Fixed some visual glitches when running under compositors that forced foot
    to double-buffer (KWin, those based on Smithay, etc).
  * See https://codeberg.org/dnkl/foot/releases/tag/1.19.0 for more details.
* Wed Aug 14 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.18.1:
  * foot.ini options:
  * desktop-notifications.command config can now also use "${muted}"
    and "${sound-name}" in its template value.
  * CSD buttons now activate on mouse button release, rather than press.
  * Desktop notifications via OSC-99 sequence can now choose to play
    a particular sound or mute the sound.
  * Fixed bug in OSC-111 sequence used to reset background color not handling
    alpha changes correctly, causing visual glitches.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.18.1 for more details.
* Fri Aug  2 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.18.0:
  * foot.ini options:
  * Added cursor.blink-rate option to configure the rate the cursor
    blinks with.
  * Deprecated main.notify and main.notify-focus-when-inhibit options
    and added new desktop-notifications option group.
    desktop-notifications.command option replaces main.notify option,
    and also takes some new templated parameters.
    desktop-notifications.inhibit-when-focused option replaces
    main.notify-focus-inhibit option.
  * Changed scrollback to respect high-resolution mousewheel scroll events
    on compositors that send them. scrollback.multiplier config option
    may need to be adjusted for users of mice that emit such events.
  * Mouse wheel events now generate BTN_WHEEL_BACK and BTN_WHEEL_FORWARD
    instead of BTN_BACK and BTN_FORWARD. The defaults of
    mouse-bindings.scrollback-up-mouse, .scrollback-down-mouse,
    .font-increase and .font-decrease have been updated accordingly.
    This means dedicated mouse buttons that do generate BTN_BACK and
    BTN_FORWARD can now be bound independently from the scroll wheel.
  * Added support for rendering colored and styled (wavy) underlines
    ala Kitty, double underlines, color palette stack,
    in-band resize notifications to applications and
    Kitty desktop notifications protocol.
  * Added new themes: catppuccin-frappe, catppuccin-latte,
    catppuccin-macchiato, catppuccin-mocha, nvim-dark, nvim-light.
  * Fixed various crashes, compatibility issues with terminal codes
    and other bugs.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.18.0 for more details.
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add package sig and developer keyring
* Wed Apr 17 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.17.2:
  * OSC notifications with invalid UTF-8 strings are now ignored.
  * Fixed various crashes.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.17.2 for more details.
* Thu Apr 11 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.17.1:
  * foot.ini options:
  * Added cursor.unfocused-style option to control the look of the cursor
    when the window is not focused.
  * Added key-bindings.quit option.
  * Fixed syslog logging from foot-server to respect log level option.
  * Fixed terminal to not shut down until the client application exits,
    even if the client application closed the PTY.
  * When closing the window, foot now sends SIGHUP to the client application
    before SIGTERM and SIGKILL. Previously it only sent SIGTERM and SIGKILL.
  * Fixed crash from malformed DECRQSS request.
  * Added new themes - dracula-iterm, noirblaze, xterm.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.17.1 for more details.
* Tue Apr  2 2024 Arnav Singh <opensuse@arnavion.dev>
- Fix rpmlint warning no-%%check-section.
* Tue Apr  2 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.17.0:
  * foot.ini options:
  * Added main.resize-by-cells option, enabled by default, that constrains
    the size of floating windows to multiples of the cell size.
  * Key bindings now support custom modifiers other than
    Ctrl / Shift / Alt / Super.
  * Added key-bindings.pipe-command-output option to copy the last command's
    output to clipboard.
  * ARGB color values that don't specify the alpha value now default
    to opaque rather than transparent.
  * key-bindings.font-increase and font-decrease now include
    Ctrl+wheel up and Ctrl+wheel down by default, in addition to the existing
    Ctrl-+ and Ctrl+-.
  * Added support for opening an existing PTY, e.g. a VM console.
  * Unicode input mode now accepts input from the numpad as well,
    numlock is ignored.
  * Various changes related to ANSI escape sequences, foot-extra terminfo,
    Kitty keyboard protocol implementation, and sixels.
  * Fixed various crashes.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.17.0 for more details.
* Thu Feb 29 2024 Max Lin <mlin@suse.com>
- Define _distconfdir macro on Leap 15
* Tue Oct 17 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.16.2:
  * Fixed bug in rendering some sixels with edges of the wrong color.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.16.2 for more details.
* Thu Oct 12 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.16.1:
  * Fixed rendering cells underneath erased sixels.
  * Fixed being unable to start on kernel versions before 6.3.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.16.1 for more details.
* Wed Oct 11 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.16.0:
  * foot.ini options:
  * Mouse wheel scroll can now be bound to actions, as BTN_BACK for
    scrolling up and BTN_FORWARD for scrolling down.
  * Added mouse-bindings.scrollback-up-mouse and
    mouse-bindings.scrollback-down-mouse options to scroll contents.
    Default to BTN_BACK and BTN_FORWARD.
  * Changed default mouse-bindings.select-row from BTN_LEFT-3
    (triple left click) to BTN_LEFT-4 (quadruple left click).
  * Added mouse-bindings.select-quote option to select an entire quote and
    copy it. Defaults to BTN_LEFT-3 (triple left click).
  * Added many search-bindings.extend-* options to extend the selection
    of a search match.
  * Added many search-bindings.scrollback-* options to scroll the contents
    in search mode.
  * Added bell.visual option to control if the BEL character will cause
    the window to flash. Defaults to "no".
  * Added colors.flash and colors.flash-alpha options to set the color of
    the window when it flashes.
  * Added support for grapheme cluster processing support to be
    queried and modified by applications that support it.
  * Changed URL mode to not strip file:// prefix from local file URIs.
  * Changed rendering to have lower latency in many cases, especially on
    high DPI monitors.
  * Fixed wrong baseline offset for some fonts.
  * Fixed foot-server systemd units to only start after the wayland session
    is fully initialized.
  * Fixed URL mode to work with URLs containing double-width characters and
    grapheme clusters.
  * Fixed margins to become non-transparent in full-screen mode, for
    compliance with the current Wayland protocol specification.
  * Fixed command-line configuration overrides to take effect even if
    the foot.ini does not exist or cannot be parsed.
  * Fixed some crashes related to fractional scaling, XDG activation and
    search mode.
  * Added new theme - panda.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.16.0 for more details.
* Mon Aug  7 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.15.3:
  * Fixed -f,--font command line option not affecting the font used for CSDs.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.15.3 for more details.
* Sun Jul 30 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.15.2:
  * foot.ini options:
  * Added tweak.bold-text-in-bright-amount option.
  * Fixed various crashes related to copy-paste, font sizes, wayland support
    of compositor, and more.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.15.2 for more details.
* Fri Jul 21 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.15.1:
  * Background transparency (alpha) is now disabled in fullscreened windows.
  * systemd service and socket units of foot-server are no longer instanced
    on the WAYLAND_DISPLAY env var. They are now singletons and part of
    the standard graphical-session.target. This also means the socket path
    does not incorporate the WAYLAND_DISPLAY value. The list of socket paths
    that footclient tries to connect to has been updated accordingly.
  * Fixed various bugs related to fractional scaling, font sizes, and more.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.15.1 for more details.
* Fri Jul 14 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.15.0:
  * foot.ini options:
  * Added csd.double-click-to-maximize option. Defaults to "yes".
  * Added touch.long-press-delay option.
  * Renamed main.utempter option to main.utmp-helper. main.utempter is still
    recognized, but will log a deprecation warning.
  * Changed default main.dpi-aware value from "auto" to "no", and "auto" is
    no longer an allowed value.
  * Default theme is now "starlight".
  * Changed default key-bindings.show-urls-launch from Ctrl-Shift-U to
    Ctrl-Shift-O.
  * Changed default key-bindings.unicode-input from none to Ctrl-Shift-U.
  * Implemented support fractional scaling on compositors that implement
    the fractional-scale-v1 Wayland protocol. This also changes how fonts
    are scaled to be based on the output scale factor configured in
    the compositor rather than the output's DPI. To restore
    the original behavior, set main.dpi-aware to "yes".
  * Implemented support server side cursor shapes on compositors that implement
    the cursor-shape-v1 Wayland protocol.
  * Implemented support for touchscreen input.
  * Implemented XTQMODKEYS query (CSI ? Pp m).
  * Added new themes - aeroroot, ayu-mirage, srcery, starlight.
  * Fixed incorrect icon in dock and window switcher on GNOME.
  * Fixed various bugs in sixel output.
  * Fixed various crashes when resizing or scrolling.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.15.0 for more details.
- Patches:
  * Drop 0000-fix-scroll-damage-crash.patch
  * Drop 0001-fix-crash-when-reflowing-alt-screen.patch
  * Drop 0002-ensure-scroll-region-endpoint-is-valid-after-a-window-resize.patch
  * Drop 0003-keep-empty-bottom-scroll-margin-empty-after-resize.patch
  * Drop 0004-fix-non-utf8-complaint.patch
  * Drop 0005-fix-wayland-protocols-1.32.patch
* Mon Jul  3 2023 Arnav Singh <opensuse@arnavion.dev>
- Add patch 0005-fix-wayland-protocols-1.32.patch.
  * wayland: handle enum value XDG_TOPLEVEL_STATE_SUSPENDED
* Tue Jun 27 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Modify 0002-ensure-scroll-region-endpoint-is-valid-after-a-window-resize.patch
* Mon Jun 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add patches
  * 0003-keep-empty-bottom-scroll-margin-empty-after-resize.patch
  * 0004-fix-non-utf8-complaint.patch
* Mon Jun 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0002-ensure-scroll-region-endpoint-is-valid-after-a-window-resize.patch
  * render: ensure scroll region’s endpoint is valid after a window resize
* Mon Jun 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0001-fix-crash-when-reflowing-alt-screen.patch
  * render: resize: fix crash when reflowing the alt screen
* Mon Jun 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-fix-scroll-damage-crash.patch.
  * term: scroll: only record scroll damage when viewport is at the bottom.
* Sat Apr 22 2023 Arnav Singh <opensuse@arnavion.dev>
- Fix dependency on tllist to be >=1.1.0 since the code uses a feature
  not found in older versions.
* Wed Apr  5 2023 Arnav Singh <opensuse@arnavion.dev>
- Add dependency on utempter explicitly since it's not picked up automatically.
* Wed Apr  5 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.14.0:
  * foot.ini options:
  * Added font-size-adjustment option to set the font size change increment
    when zooming in or out.
  * Added underline-thickness option to set underline height.
  * Changed default colors to correspond to the solarized-dark-normal-brights
    theme.
  * Added main.utempter option to set path to utempter binary, used to
    create utmp records. Defaults to the path of that binary at build time.
  * Changed default grapheme-width-method option to double-width.
  * Changed default pad option to 0x0.
  * String values can now be quoted with double quotes (""), which can be
    used to set an option to an empty string value. For environment variables
    setting them to the empty string unsets them.
  * Added various terminfo capabilities to work better with vim, etc.
  * Fixed various crashes.
  * Added new themes - deus, material-amber, modus, moonfly, nightfly, onedark,
    rose-pine, zenburn.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.14.0 for more details.
* Wed Aug 31 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.13.1:
  * Window is now dimmed while in Unicode input mode.
  * Fix crash on some compositors like GNOME.
  * Fix crash when resizing the window or scrolling in scrollback history.
  * Fix empty cells being highlighted as selected when they shouldn't be.
  * Fix separate URLs being connected in URL mode if they have the same ID.
* Sun Aug  7 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.13.0:
  * foot.ini options:
  * Added colors.search-box-no-match and colors.search-box-match options.
  * Added new environment section to define custom environment variables for
    child processes.
  * Added key-bindings.prompt-prev and key-bindings.prompt-next options.
    These key bindings jump to the previous / next prompt with a cooperating
    shell.
  * Added key-bindings.unicode-input and search-bindings.unicode-input
    options. They provide a way to input unicode using codepoints without
    an external IME.
  * Client-side decorations no longer show buttons that do nothing because
    the compositor doesn't support the button's feature. For example,
    the minimize button won't be shown if the compositor doesn't support
    minimizing.
  * Added new themes - Monokai Pro, Catppuccin, Tokyo Night,
    Tokyo Night Day, Tokyo Night Storm.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.13.0 for more details.
- Mark foot-extra-terminfo and foot-themes packages as noarch.
- Remove redundant copy of doc files and license in $datadir/doc/foot/
* Wed Apr 27 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.12.1:
  * foot.ini options:
  * search-bindings.clipboard-paste now includes Ctrl-Shift-V and XF86Paste
    by default.
  * search-bindings.extend-to-word-boundary command no longer stops at
    space-to-word boundaries.
  * Fixed some issues related to scrollback search mode.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.12.1 for more details.
* Fri Apr 22 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to v1.12.0:
  * foot.ini options:
  * Added key-bindings.scrollback-home and .scrollback-end options.
  * Added key-binding.show-urls-persistent option. This is similar to
    show-urls-launch, but remains in URL mode after activating an URL.
  * Added tweak.sixel option to allow disabling sixel support.
  * Added csd.hide-when-maximized option to hide the CSD when maximized.
  * Implemented socket activation support for foot --server, along with
    sample systemd user session units.
  * footclient now has a -E,--client-environment parameter to inherit
    its environment from its parent process instead of the foot server.
  * Implemented support for more terminal sequences.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.12.0 for more details.
- Set all options and features explicitly instead of relying on auto-detection
  to ensure build fails if dependencies change.
- Upstream moved default foot.ini from $datadit/foot/foot.ini
  to $sysconfdir/xdg/foot/foot.ini . Move it ourselves
  to $distconfdir/xdg/foot/foot.ini in accordance with packaging guidelines
  for new packages.
- Patches:
  * Drop foot-tests-missing-deps.patch
* Thu Mar 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add "Requires: foot" for foot-themes package
* Thu Mar 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Make foot-themes a subpackage of foot.
- Fix foot-themes summary and description.
* Sat Feb  5 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.11.0:
  * foot.ini options:
  * Added mouse-bindings.selection-override-modifiers option to specify
    which modifiers should be held to force selection and prevent
    client applications from grabbing the mouse.
  * scrollback.multiplier is now also applied in alternate-scroll mode.
    The client receives multiple arrow key presses equal to
    the multiplier instead of just one.
  * key-bindings.clipboard-{copy,paste} now support
    the XF86{Copy,Paste} keycodes.
  * irc:// and ircs:// URLs are now auto-detected as URLs.
  * Added support for reporting mouse coordinates in SGR-Pixels (1016) format.
  * Added XTGETTCAP support for reporting the current terminfo to clients
    that support it instead of needing the terminfo file installed,
    say when ssh'ing to remote hosts.
  * Added partial DECRQSS support so that clients can request
    top and bottom margins (DECSTBM), graphic rendition (SGR) and
    cursor style (DECSCUSR).
  * Searching the scrollback now defaults to searching for
    the previously-searched string.
  * PaperColorDark and PaperColorLight themes have been renamed to
    paper-color-dark and paper-color-light for consistency with other themes.
  * foot will now try to change the locale to either C.UTF-8 or en_US.UTF-8
    on startup if it has been started with a non-UTF-8 locale. If it fails to
    change the locale for any reason, it will show an error and not start
    the shell / program it was supposed to.
  * Pasting or dropping files on the alternate screen no longer quotes
    the filename.
  * Copying a line-based selection now includes a trailing newline.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.11.0 for more details.
- Patches:
  * Add foot-tests-missing-deps.patch to add missing wayland-client dependency
    to tests subdirectory, as discussed with upstream.
* Wed Dec  8 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.3:
  * Implemented support for all other modes of the Kitty keyboard protocol.
    See Kitty keyboard protocol docs for more details.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.3 for more details.
* Thu Dec  2 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.2:
  * foot.ini options:
  * tweak.grapheme-width-method can now be set to max, which means to use
    the width of the largest codepoint in the grapheme cluster.
  * Added initial support for Kitty keyboard protocol, currently with support
    for only the "Disambiguate escape codes" mode. See Kitty keyboard protocol
    docs for more details.
  * Right-clicking the CSD title bar now informs the Wayland compositor to show
    a window context menu, if the compositor supports such a thing in general.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.2 for more details.
* Mon Nov 22 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.1:
  * Fixed bugs in parsing foot.ini for letter-spacing, pipe-* key bindings, etc
    that were introduced in 1.10.0.
  * Added XDG desktop file for footclient.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.1 for more details.
* Sun Nov 21 2021 Arnav Singh <opensuse@arnavion.dev>
- Rename foot-direct-extra terminfo file to foot-extra-direct, to match
  upstream's wishes.
* Sun Nov 14 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.0:
  * foot.ini options:
  * Added notify-focus-inhibit boolean option to control whether
    desktop notifications should be inhibited when the terminal
    has keyboard focus.
  * Added colors.scrollback-indicator color-pair option to specify foreground
    and background colors for the scrollback indicator.
  * Added csd.border-width and csd.border-color to configure the width and
    color of the CSD border.
  * Added colors.dim0-7 options to configure custom "dim" colors.
  * Changed tweak.grapheme-shaping to be enabled by default.
  * Changed tweak.grapheme-width-method to be "wcswidth" by default.
  * All boolean options are now limited to "yes|true|on|1|no|false|off|0".
    Previously any numbers greater than 0 were treated as true, and anything
    else that wasn't "yes|true|on" was treated as false.
  * scrollback.multiplier is no longer applied when the alternate screen
    is in use.
  * Removed deprecated bell option. bell section (introduced in 1.8.0) should
    be used instead.
  * Removed deprecated url-launch, jump-label-letters and
    osc8-underline-options options. url section (introduced in 1.8.0) should
    be used instead.
  * Some pre-defined color themes are now available in /usr/share/foot/themes/
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.0 for more details.
* Thu Oct 14 2021 Arnav Singh <opensuse@arnavion.dev>
- Fix default TERM to be "foot" and not "foot-extra" as was intended.
- Add dependency on terminfo package since that is the package that ships
  ncurses upstream's terminfo for foot, not terminfo-base.
* Mon Oct  4 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.9.2:
  * foot.ini options:
  * New tweak.font-monospace-warn option to disable new warning when
    the primary font is not monospace.
  * dpi-aware=auto option now scales fonts using the monitor's DPI only when
    all monitors have a scaling factor of one.
  * foot's custom terminfos have been moved to the foot-extra-terminfo package,
    where they have been renamed to foot-extra. By default, foot no longer
    sets TERMINFO and expects to use the terminfo shipped by ncurses. If you
    want to use the customer terminfos instead, install
    the foot-extra-terminfo package and set term=foot-extra in
    your foot config.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.9.1 and
    https://codeberg.org/dnkl/foot/releases/tag/1.9.2 for more details.
* Fri Aug 27 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.9.0:
  * foot.ini options:
  * include directives for including files now expand ~ in the path.
  * New uri.uri-characters option to customize what characters are considered
    to be part of a URL.
  * If using a compositor with client-side decorations, the CSDs now show
    window titles.
  * foot's terminfo file is now installed under /usr/share/foot/terminfo
    so as to not conflict with terminfo-base's version of the file
    under /usr/share/terminfo. foot also sets the TERMINFO env var on
    the program to /usr/share/foot/terminfo so that the program prefers to
    use the file in this directory instead of terminfo-base's version.
    This is because terminfo-base's version does not expose all the capabilities
    that foot supports.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.9.0 for more details.
* Sun Jul 18 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.8.2:
  * New foot.ini options:
  * locked-title option to disable dynamic changes to the window title.
  * tweak.overflowing-glyps option to fix rendering issues with glyphs of
    any width that appear cut-off. This supersedes
    the tweak.allow-overflowing-double-width-glyphs and
    tweak.pua-double-width options, which have been removed.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.8.2 for more details.
* Thu Jul  1 2021 Arnav Singh <opensuse@arnavion.dev>
- Delete 01-fix-xkbcommon-missing-dep.7edda924.patch since it is in upstream
  since 1.8.0
* Thu Jul  1 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.8.1:
  * New foot.ini options:
  * cursor.beam-thickness
  * cursor.style=beam (cursor.style=bar remains a recognized value, but will
    will eventually be deprecated, and removed)
  * cursor.underline-thickness
  * underline-offset
  * csd.button-color
  * dedicated [bell] section, supporting multiple actions,
    a new command action to run an arbitrary command and
    XDG activation support. The bell option has been deprecated.
  * dedicated [url] section. The jump-label-letters, osc8-underline and
    url-launch options have been deprecated in favor of options in
    this new section.
  * tweak.grapheme-shaping option to foot.ini to support
    grapheme cluster segmentation and grapheme shaping.
    The grapheme cluster width is limited to two cells by default,
    which may cause cursor synchronization issues with many applications.
  * tweak.grapheme-width-method=wcswidth option to stop limiting
    grapheme cluster width to two cells.
  * tweak.pua-double-width option to foot.ini to force
    Private Usage Area codepoints to be treated as double-width characters.
  * Added support for including files in foot.ini
  * Added support for setting the full 256 color palette in foot.ini
  * Added ctrl+c as a default key binding; to cancel search/url mode.
  * Added support for overriding configuration options on the command line.
  * Added support for DECSET/DECRST 2026, as an alternative to the existing
    "synchronized updates" DCS sequences.
  * Added support for LS2 and LS3 (locking shift) escape sequences.
  * Added OSC 9 desktop notifications (iTerm2 compatible).
  * See https://codeberg.org/dnkl/foot/releases/tag/1.8.0 and
    https://codeberg.org/dnkl/foot/releases/tag/1.8.1 for more details.
* Sat Jun 12 2021 Jan Engelhardt <jengelh@inai.de>
- Remove unsubstantiated claims from descriptions.
* Fri Jun 11 2021 Arnav Singh <opensuse@arnavion.dev>
- Fix specfile to use correct URL, meson dependency to match upstream,
  and remove incorrect Group. Also use autosetup macro instead of setup.
* Fri Jun 11 2021 Arnav Singh <opensuse@arnavion.dev>
- Initial package of 1.7.2 for openSUSE
